@@ -30,12 +30,16 @@
 #include "cscmi.h"
 #include "draw.h"
 #include "events.h"
+#include "statistics.h"
 
 static GtkWidget *about = NULL;
 
 static void restart_game ()
 {
   if (waiting_for_mouse_up()) return;
+  /* Treat a restart as part of the same game. Eventually either
+   * the player will win or loose and then it gets counted. */
+  game_in_progress = FALSE;
   new_game (NULL, &seed);
 };
 
@@ -89,7 +93,7 @@ void help_about_callback ()
 	  NULL
   };
 
-  const gchar *translator_credits = _("translator_credits");
+  const gchar *translator_credits = _("translator-credits");
 	char *filename = NULL;
 
 	filename = gnome_program_locate_file (NULL,
@@ -112,13 +116,13 @@ void help_about_callback ()
   }
   about = gnome_about_new ( _("AisleRiot"), VERSION,
 			    /* copyright notice */
-			    "Copyright \xc2\xa9 1998-2003 Jonathan Blandford",
+			    "Copyright \xc2\xa9 1998-2004 Jonathan Blandford",
 			    _("AisleRiot provides a rule-based solitaire card "
 			      "engine that allows many different games to be "
 			      "played."),
 			    (const char **)authors,
 			    (const char **)documenters,
-			    g_str_equal (translator_credits, "translator_credits") ? NULL : translator_credits,
+			    g_str_equal (translator_credits, "translator-credits") ? NULL : translator_credits,
 			    pixbuf);
 	
 	if (pixbuf != NULL)
@@ -171,11 +175,7 @@ GnomeUIInfo rules_sub_menu[] = {
   GNOMEUIINFO_END
 };
 
-GnomeUIInfo file_menu[] = {
-  GNOMEUIINFO_END
-};
-
-GnomeUIInfo settings_menu[] = {
+GnomeUIInfo view_menu[] = {
 
 #if 0
   GNOMEUIINFO_ITEM_STOCK(N_("Game _options..."),
@@ -188,7 +188,8 @@ GnomeUIInfo settings_menu[] = {
   GNOMEUIINFO_TOGGLEITEM (N_("_Toolbar"), N_("Show or hide the toolbar"),
                           toolbar_toggle_callback, NULL),
 
-  GNOMEUIINFO_MENU_PREFERENCES_ITEM(show_preferences_dialog, NULL),
+  GNOMEUIINFO_ITEM_STOCK (N_("_Cards..."), N_("Change the appearance of the cards"), 
+			  show_preferences_dialog, NULL),
 
   GNOMEUIINFO_END
 };
@@ -209,6 +210,8 @@ GnomeUIInfo game_menu[] = {
 
   GNOMEUIINFO_ITEM_STOCK (N_("_Select..."), N_("Select a different game"), show_select_game_dialog, GTK_STOCK_OPEN),
 
+  GNOMEUIINFO_ITEM_STOCK (N_("S_tatistics..."), N_("Get statistics on the current game"), show_statistics_dialog, GTK_STOCK_ADD),
+
   GNOMEUIINFO_SEPARATOR,
 
   GNOMEUIINFO_MENU_UNDO_MOVE_ITEM(undo_callback, NULL),
@@ -237,7 +240,7 @@ GnomeUIInfo top_menu[] = {
 
   GNOMEUIINFO_MENU_GAME_TREE(game_menu),
 
-  GNOMEUIINFO_MENU_SETTINGS_TREE(settings_menu),
+  GNOMEUIINFO_MENU_VIEW_TREE(view_menu),
 
   GNOMEUIINFO_MENU_HELP_TREE(help_menu),
 
@@ -286,7 +289,7 @@ void create_menus ()
   gnome_app_create_menus (GNOME_APP(app), top_menu);
   gnome_app_create_toolbar (GNOME_APP(app), toolbar);
 
-  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (settings_menu[0].widget),
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_menu[0].widget),
                                   gconf_client_get_bool (gconf_client,
                                                          "/apps/aisleriot/show_toolbar",
                                                          NULL));
